import { date } from "@/utils/moment";
import { version } from "../../package.json";
import { tracking } from "@/api/tracking";

export default {
  data() {
    return {
      activeTime: 0,
      destroyTime: 0,
      initTime: "",
      // 系统名/模块名/页面名
      names: {
        sysName: "",
        modName: "",
        pageName: "",
      },
      platform: "websit",
      appOs: "js",
      clientWidth: 0,
      clientHeight: 0,
      browVersion: "",
      pageUrl: "",
      pageRef: "ceshi",
      actionName: "",
      pageTime: "1000",
      browser: "",
      browserVersion: "",
      actionType: "page",
    };
  },
  created() {},
  async mounted() {
    // 记录页面名称
    const { matched, fullPath, name, meta } = this.$route;
    this.pageUrl = fullPath;
    this.actionName = name || "no-name";
    console.log(meta);
    // const nameKeys = Object.keys(this.names);
    // matched.forEach((route, index) => {
    //   const name = nameKeys[index];
    //   this.names[name] = route.name;
    // });
    this.names.sysName = meta.sysName || "";
    this.names.modName = meta.modName || "";
    this.names.pageName = meta.pageName || "";
    // 记录初始化页面时间
    this.activeTime = new Date().getTime();
    this.initTime = date();
    // 获取浏览器宽高
    this.clientWidth = document.body.clientWidth;
    this.clientHeight = document.body.clientHeight;
    // 获取浏览器及其版本
    this.browser = this.getBrowserInfo().toString().split("/")[0];
    this.browserVersion = this.getBrowserInfo().toString().split("/")[1];
    try {
      const data = {
        appVersion: version,
        platform: this.platform,
        appOs: this.appOs,
        resolution: `${this.clientWidth} * ${this.clientHeight}`,
        browVersion: `${this.browser} ${this.browserVersion}`,
        pageUrl: this.pageUrl,
        pageRef: this.pageRef,
        sysName: this.names.sysName,
        modName: this.names.modName,
        pageName: this.names.pageName,
        actionName: this.actionName,
        pageTime: this.pageTime,
        actionType: this.actionType,
        source: process.env.VUE_APP_ENV
      };
      const result = await tracking(data);
      if (!result.success) {
        console.log(result.msg);
      }
    } catch (error) {
      console.log(error);
    }
  },
  beforeDestroy() {
    // 记录销毁页面时间
    this.destroyTime = new Date().getTime();
  },
  methods: {
    // 获取浏览器信息
    getBrowserInfo() {
      const agent = navigator.userAgent.toLowerCase();
      const regStrIe = /msie [\d.]+;/gi;
      const regStrFf = /firefox\/[\d.]+/gi;
      const regStrChrome = /chrome\/[\d.]+/gi;
      const regStrSaf = /safari\/[\d.]+/gi;
      // IE
      if (agent.indexOf("msie") > 0) {
        return agent.match(regStrIe);
      }
      // firefox
      if (agent.indexOf("firefox") > 0) {
        return agent.match(regStrFf);
      }
      // Chrome
      if (agent.indexOf("chrome") > 0) {
        return agent.match(regStrChrome);
      }
      // Safari
      if (agent.indexOf("safari") > 0 && agent.indexOf("chrome") < 0) {
        return agent.match(regStrSaf);
      }
    },
  },
};
