import store from '@/store'

/**
 * 获取表头过滤数组
 * @param {Array} data 列表数据 
 * @param {String} columnKey  过滤Column的Key
 * @param {Function} fn  自定义过滤方法 主要为了表格列展示和后端数据不一致
 * @returns 
 */
export function filterColumn (data, columnKey, fn) {
    let filterCol = data.map((item) => {
        if (fn) {
           return fn.call(this, item)
        }
        return {
            text: item[columnKey],
            value: item[columnKey]
        }
    })
    return deWeight(filterCol, 'value')
}

export function deWeight(arr, key) {
    for (var i = 0; i < arr.length - 1; i++) {
        for (var j = i + 1; j < arr.length; j++) {
            if (arr[i][key] == arr[j][key]) {
                arr.splice(j, 1);
                //因为数组长度减小1，所以直接 j++ 会漏掉一个元素，所以要 j--
                j--;
            }
        }
    }
    return arr;
}

/**
 * 判断数组中是否存在某个对象返回Index
 * @param {Array} list 
 * @param {String} key 
 * @param {Object} obj 
 * @returns 
 */
 export function hasObject (list, key, obj) {
    for(let i = 0; i < list.length; i++) {
        if (list[i][key] === obj[key]) {
            return i
        }
    }
    return -1
}
/**
 * 处理金额
 * @param {*} num 金额:1000/100.00
 * @returns 返回默认保留两位小数的金额
 */
export function formaNum(num){
  num = num + "";
  let a= num.split('.')[0].split("").reverse().reduce((s,item,index)=>{
        return (index%3?item:item+",")+s
   });
   return num.split('.')[1] && num.split('.')[1].length>0?parseFloat(a+"."+num.split('.')[1]).toFixed(2)+"":a+".00";
}

// permissionList 需要做权限的数组
// tag 权限标识
// type 1 tabs , 2 别的权限
export function hasPermission (permissionList,tag,type) {
  const permissionAllList = store.state.globalState.globalState.permissionOperations || [];
  const flag = permissionList.includes(tag);
  const permissionFlag = permissionAllList.some(item => item.authorityExplain === tag)
  // const permissionFlag = permissionAllList.includes(tag);

  if(type==1){
    return (!flag && permissionFlag)
  }else {
    return permissionFlag
  }

}

export function showDesensitizationText(obj) {
  if (!obj) {
    return '';
  }
  if(obj.icon == 0) return obj.desensitizedValue || '';
  if(obj.icon == 1) return obj.originalValue || '';
  return obj.desensitizedValue || ''
}

export function showDesensitizationIcon(obj) {
  return obj.icon == 2;
}